Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Version ¶
func Version() string
Version returns the library version string in SemVer format (without `v`).
func VersionIsSemver ¶
func VersionIsSemver() bool
VersionIsSemver reports whether the embedded Version is valid SemVer.
func VersionTag ¶
func VersionTag() string
VersionTag returns the git tag form of Version (with leading `v`).
Types ¶
This section is empty.
Directories
¶
| Path | Synopsis |
|---|---|
|
Package buffer implements the pure, grapheme-accurate document model for Flourish.
|
Package buffer implements the pure, grapheme-accurate document model for Flourish. |
|
Package editor provides a Bubble Tea text editor component backed by the buffer package.
|
Package editor provides a Bubble Tea text editor component backed by the buffer package. |
|
examples
|
|
|
completion-popup
command
|
|
|
conditional-styling
command
|
|
|
highlighter
command
|
|
|
inline-suggestions
command
|
|
|
intent-mode
command
|
|
|
on-change
command
|
|
|
row-marks
command
|
|
|
scrollbar
command
|
|
|
simple
command
|
|
|
virtual-text
command
|
|
|
wrap-modes
command
|
|
|
internal
|
|
Click to show internal directories.
Click to hide internal directories.